@@ -281,7 +281,7 @@ class PooledDB(Pool_db.PooledDB):
         # Establish an initial number of idle database connections:
         idle = [self.dedicated_connection() for i in range(mincached)]
         while idle:
-            idle.pop().close()
+            idle.pop().close()  # 后进先出
         # 开启空闲线程检查
         if self.testIdle and self.idleCheckTime > 0:
             t = Timer(self.idleCheckTime, self.start_check_idle, [self.idleCheckTime])
@@ -297,7 +297,7 @@ class PooledDB(Pool_db.PooledDB):
             self._lock.acquire()
             try:
                 while len(self._idle_cache) > self._mincached:
-                    self._idle_cache.pop(0).close()
+                    self._idle_cache.pop().close()  # 后进先出
                     # self._connections -=1
                 self._lock.notify()
             finally:
@@ -464,8 +464,15 @@ def exec_sql(conn, sql, params=()):
     except Exception as e:
         raise e
     finally:
+        close_cursor(cus)
+
+
+def close_cursor(cus):
+    try:
         if cus:
             cus.close()
+    except Exception as e:
+        pass
 
 
 class ResultThread(threading.Thread):
